@@ -124,7 +124,7 @@ class MetadataClientTest(ModuleBase, unittest.TestCase):
 
         self.assert_eq_val(resp['app_info'], 'Resource not found!')
         self.assert_eq_val(resp['success'], False)
-        self.assert_eq_val(resp['info'], 'proposal not found!')
+        self.assert_eq_val(resp['info'], 'Error getting proposal')
         self.assert_eq_val(resp['data'], {})
 
     def test_get_proposal_experiments_with_errors(self):
@@ -143,7 +143,7 @@ class MetadataClientTest(ModuleBase, unittest.TestCase):
         #         'app_info': 'Proposal number -99 not found',
         #         'data': {}}
 
-        self.assert_eq_val(resp['info'], 'proposal not found!')
+        self.assert_eq_val(resp['info'], 'Error getting proposal')
         self.assert_eq_val(resp['success'], False)
         self.assert_eq_val(resp['app_info'], 'Proposal number -99 not found')
         self.assert_eq_val(resp['data'], {})
@@ -218,7 +218,7 @@ class MetadataClientTest(ModuleBase, unittest.TestCase):
         #         'data': 'Proposal number -99 not found',
         #         'app_info': {}}
 
-        self.assert_eq_val(resp['info'], 'proposal not found!')
+        self.assert_eq_val(resp['info'], 'Error getting proposal')
         self.assert_eq_val(resp['success'], False)
         self.assert_eq_val(resp['app_info'], 'Proposal number -99 not found')
         self.assert_eq_val(resp['data'], {})
@@ -272,7 +272,7 @@ class MetadataClientTest(ModuleBase, unittest.TestCase):
         #         'data': 'Proposal number -99 not found',
         #         'app_info': {}}
 
-        self.assert_eq_val(resp['info'], 'proposal not found!')
+        self.assert_eq_val(resp['info'], 'Error getting proposal')
         self.assert_eq_val(resp['success'], False)
         self.assert_eq_val(resp['app_info'], 'Proposal number -99 not found')
         self.assert_eq_val(resp['data'], {})
@@ -327,6 +327,19 @@ class MetadataClientTest(ModuleBase, unittest.TestCase):
 
         self.assertEqual(prop_info['instrument_identifier'], 'SPB')
 
+    def test_get_proposal_details_error_sample(self):
+        resp = self.mdc_client.get_proposal_info(2194, ['SA1', 'SA2', 'SA3'])
+
+        # Logging information
+        logging.error('resp: {0}'.format(resp))
+
+        # Expected return:
+        #
+        self.assert_eq_val(resp['info'], 'Error getting proposal')
+        self.assert_eq_val(resp['app_info'], 'The proposal beamline status is in a finished status in myMdC!')  # noqa
+        self.assert_eq_val(resp['success'], False)
+        self.assert_eq_val(resp['data'], {})
+
     def test_get_proposal_details_error_instruments(self):
         resp = self.mdc_client.get_proposal_info(900061, ['SA1', 'SA2', 'SA3'])
 
@@ -335,9 +348,9 @@ class MetadataClientTest(ModuleBase, unittest.TestCase):
 
         # Expected return:
         #
-        self.assert_eq_val(resp['info'], "The proposal doesn\'t match this DAQ instance configured list of allowed instruments!")  # noqa
-        self.assert_eq_val(resp['success'], True)
+        self.assert_eq_val(resp['info'], 'Error getting proposal')
         self.assert_eq_val(resp['app_info'], "The proposal doesn\'t match this DAQ instance configured list of allowed instruments!")  # noqa
+        self.assert_eq_val(resp['success'], True)
         self.assert_eq_val(resp['data'], {})
 
     def test_register_run_with_invalid_keys(self):
